package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.FilFile;
import com.zhaoliangsz.grainsearch.mapper.FilFileMapper;
import com.zhaoliangsz.grainsearch.service.IFilFileService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 * 文件信息 服务实现类
 * </p>
 *
 * @author chengchangjiang
 * @since 2023-08-22 11:09:57
 */
@Slf4j
@Service
public class FilFileServiceImpl extends ServiceImpl<FilFileMapper, FilFile> implements IFilFileService {
    @Override
    public PageResult<FilFile> queryFilFileList(FilFile queryFilFile) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(queryFilFile.getCurrentPage()-1)
            *queryFilFile.getPageSize());
            pageView.put("pageSize",queryFilFile.getPageSize());
            pageView.put("currentPage",queryFilFile.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<FilFile>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[FilFileServiceImpl.queryFilFileList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addFilFile(FilFile addFilFile) throws ServiceException {
        boolean flag = this.save(addFilFile);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editFilFile(FilFile editFilFile) throws ServiceException {
        boolean flag = this.updateById(editFilFile);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteFilFile(FilFile deleteFilFile) throws ServiceException {
        boolean flag = this.removeById(deleteFilFile);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
