package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.GrainRightBoard;
import com.zhaoliangsz.grainsearch.mapper.GrainRightBoardMapper;
import com.zhaoliangsz.grainsearch.service.IGrainRightBoardService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 * 粮权牌 服务实现类
 * </p>
 *
 * @author chengchangjiang
 * @since 2023-08-22 11:09:57
 */
@Slf4j
@Service
public class GrainRightBoardServiceImpl extends ServiceImpl<GrainRightBoardMapper, GrainRightBoard> implements IGrainRightBoardService {
    @Override
    public PageResult<GrainRightBoard> queryGrainRightBoardList(GrainRightBoard queryGrainRightBoard) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(queryGrainRightBoard.getCurrentPage()-1)
            *queryGrainRightBoard.getPageSize());
            pageView.put("pageSize",queryGrainRightBoard.getPageSize());
            pageView.put("currentPage",queryGrainRightBoard.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<GrainRightBoard>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[GrainRightBoardServiceImpl.queryGrainRightBoardList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addGrainRightBoard(GrainRightBoard addGrainRightBoard) throws ServiceException {
        boolean flag = this.save(addGrainRightBoard);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editGrainRightBoard(GrainRightBoard editGrainRightBoard) throws ServiceException {
        boolean flag = this.updateById(editGrainRightBoard);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteGrainRightBoard(GrainRightBoard deleteGrainRightBoard) throws ServiceException {
        boolean flag = this.removeById(deleteGrainRightBoard);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
