package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.GrainRight;
import com.zhaoliangsz.grainsearch.mapper.GrainRightMapper;
import com.zhaoliangsz.grainsearch.service.IGrainRightService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 * 粮权 服务实现类
 * </p>
 *
 * @author chengchangjiang
 * @since 2023-08-22 11:09:57
 */
@Slf4j
@Service
public class GrainRightServiceImpl extends ServiceImpl<GrainRightMapper, GrainRight> implements IGrainRightService {
    @Override
    public PageResult<GrainRight> queryGrainRightList(GrainRight queryGrainRight) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(queryGrainRight.getCurrentPage()-1)
            *queryGrainRight.getPageSize());
            pageView.put("pageSize",queryGrainRight.getPageSize());
            pageView.put("currentPage",queryGrainRight.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<GrainRight>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[GrainRightServiceImpl.queryGrainRightList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addGrainRight(GrainRight addGrainRight) throws ServiceException {
        boolean flag = this.save(addGrainRight);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editGrainRight(GrainRight editGrainRight) throws ServiceException {
        boolean flag = this.updateById(editGrainRight);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteGrainRight(GrainRight deleteGrainRight) throws ServiceException {
        boolean flag = this.removeById(deleteGrainRight);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
