package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.SysUser;
import com.zhaoliangsz.grainsearch.mapper.SysUserMapper;
import com.zhaoliangsz.grainsearch.service.ISysUserService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 * 用户 服务实现类
 * </p>
 *
 * @author chengchangjiang
 * @since 2023-08-22 11:06:19
 */
@Slf4j
@Service
public class SysUserServiceImpl extends ServiceImpl<SysUserMapper, SysUser> implements ISysUserService {
    @Override
    public PageResult<SysUser> querySysUserList(SysUser querySysUser) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(querySysUser.getCurrentPage()-1)
            *querySysUser.getPageSize());
            pageView.put("pageSize",querySysUser.getPageSize());
            pageView.put("currentPage",querySysUser.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<SysUser>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[SysUserServiceImpl.querySysUserList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addSysUser(SysUser addSysUser) throws ServiceException {
        boolean flag = this.save(addSysUser);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editSysUser(SysUser editSysUser) throws ServiceException {
        boolean flag = this.updateById(editSysUser);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteSysUser(SysUser deleteSysUser) throws ServiceException {
        boolean flag = this.removeById(deleteSysUser);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
